@@ -1,4 +1,4 @@
-# $Id: Boolean.pm,v 1.5 2000/05/08 13:08:01 matt Exp $
+# $Id: Boolean.pm,v 1.6 2000/05/16 16:53:37 matt Exp $
 
 package XML::XPath::Boolean;
 use XML::XPath::Number;
@@ -29,7 +29,7 @@ sub to_number { XML::XPath::Number->new($_[0]->value); }
 sub to_boolean { $_[0]; }
 sub to_literal { XML::XPath::Literal->new($_[0]->value ? "true" : "false"); }
 
-sub string_value { goto &to_literal; }
+sub string_value { return $_[0]->to_literal->value; }
 
 1;
 __END__
